core-input

A single-line text input. See console for committed values.
The `type` attribute is supported. This is a single-line input with `type = password`. See console for committed values.
A multi-line text input with 3 rows. The input is normally unstyled but here is styled with a dotted border to show its size.
A multi-line text input sized with CSS. The input is normally unstyled but here is styled with a dotted border to show its size.
Inputs with the `tabindex` attribute.
Validation examples. The border color reflects the current validation state. See console for validation events.